[![Build Status](https://travis-ci.org/Frojd/wagtail-geo-widget.svg?branch=master)](https://travis-ci.org/Frojd/wagtail-geo-widget) [![PyPI version](https://badge.fury.io/py/wagtailgeowidget.svg)](https://badge.fury.io/py/wagtailgeowidget)

# Wagtail-Geo-Widget

Wagtail-Geo-Widget is the complete map solution for your Wagtail site.

![Screen1](https://raw.githubusercontent.com/frojd/wagtail-geo-widget/develop/img/screen1.png)


## Features

- Real spatial support (with GeoDjango and PointField)
- Storing coordinates as strings (for no-GeoDjango setups)
- StreamField integration
- Searching with geoencoding
- Inline panel support
- Optional address search field
- Language support


## Documentation

- [Getting started](./docs/getting-started.md)
- [Settings](./docs/settings.md)
- [Adding the widget to a Page](./docs/adding-to-a-page.md)
- [Integrating with GeoDjango](./docs/integrating-with-geodjango.md)
- [Adding to a StreamField](./adding-to-a-streamfield.md)
- [FAQ](./docs/faq.md)


## Contributing

Want to contribute? Awesome. Just send a pull request.


## License

Wagtail-Geo-Widget is released under the [MIT License](http://www.opensource.org/licenses/MIT).
